# NotificationPermission

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**put_code** | **int** |  | [optional] 
**notification_type** | **str** |  | 
**authorization_url** | [**AuthorizationUrl**](AuthorizationUrl.md) |  | 
**notification_subject** | **str** |  | [optional] 
**notification_intro** | **str** |  | [optional] 
**items** | [**Items**](Items.md) |  | 
**created_date** | **datetime** |  | [optional] 
**sent_date** | **datetime** |  | [optional] 
**read_date** | **datetime** |  | [optional] 
**actioned_date** | **datetime** |  | [optional] 
**archived_date** | **datetime** |  | [optional] 
**source** | [**Source**](Source.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


